#  This file is part of FAST-OAD : A framework for rapid Overall Aircraft Design
#  Copyright (C) 2022 ONERA & ISAE-SUPAERO
#  FAST is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.


import sys

if sys.version_info < (3, 10):
    from importlib_metadata import distribution, PackageNotFoundError
else:
    from importlib.metadata import distribution, PackageNotFoundError

try:
    # Change here if project is renamed and does not equal the package name
    dist_name = "FAST-OAD"
    __version__ = distribution(dist_name).version
except PackageNotFoundError:
    __version__ = "unknown"
finally:
    del distribution
